<?php

namespace Drupal\layout_builder_base_library\Plugin\Layout;

use Drupal\layout_builder_base\Plugin\Layout\DefaultLayoutBase;

/**
 * Configurable layout plugin class.
 *
 * @internal
 *   Plugin classes are internal.
 */
class BaseOneColumnLayout extends DefaultLayoutBase {

  /**
   * {@inheritdoc}
   */
  protected function getBackgroundOptions() {
    return [
      'layout--background--none' => $this->t('None'),
      'layout--background--white' => $this->t('White'),
      'layout--background--grey' => $this->t('Grey'),
      'layout--background--black' => $this->t('Black'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getBackgroundImageStyleOptions() {
    return [
      '' => $this->t('None'),
      'thumbnail' => $this->t('Thumbnail'),
      'medium' => $this->t('Medium'),
      'large' => $this->t('Large'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getBackgroundAttachmentOptions() {
    return [
      'layout--background-attachment--default' => $this->t('Default'),
      'layout--background-attachment--fixed' => $this->t('Fixed'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getBackgroundPositionOptions() {
    return [
      'layout--background-position--default' => $this->t('Default'),
      'layout--background-position--center' => $this->t('Center'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getBackgroundSizeOptions() {
    return [
      'layout--background-size--default' => $this->t('Default'),
      'layout--background-size--cover' => $this->t('Cover'),
      'layout--background-size--contain' => $this->t('Contain'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getBackgroundOverlayOptions() {
    return [
      'layout--background-overlay--none' => $this->t('None'),
      'layout--background-overlay--dark' => $this->t('Dark'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getEqualTopBottomMarginsOptions() {
    return [
      'layout--top-bottom-margin--none' => $this->t('None'),
      'layout--top-bottom-margin--small' => $this->t('Small margins'),
      'layout--top-bottom-margin--default' => $this->t('Default margins'),
      'layout--top-bottom-margin--big' => $this->t('Big margins'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getEqualLeftRightMarginsOptions() {
    return [
      'layout--left-right-margin--none' => $this->t('None'),
      'layout--left-right-margin--small' => $this->t('Small margins'),
      'layout--left-right-margin--default' => $this->t('Default margins'),
      'layout--left-right-margin--big' => $this->t('Big margins'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getEqualTopBottomPaddingsOptions() {
    return [
      'layout--top-bottom-padding--none' => $this->t('None'),
      'layout--top-bottom-padding--small' => $this->t('Small paddings'),
      'layout--top-bottom-padding--default' => $this->t('Default paddings'),
      'layout--top-bottom-padding--big' => $this->t('Big paddings'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getEqualLeftRightPaddingsOptions() {
    return [
      'layout--left-right-padding--none' => $this->t('None'),
      'layout--left-right-padding--small' => $this->t('Small paddings'),
      'layout--left-right-padding--default' => $this->t('Default paddings'),
      'layout--left-right-padding--big' => $this->t('Big paddings'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getContainerOptions() {
    return [
      'layout--container--default' => $this->t('Default'),
      'layout--container--none' => $this->t('None'),
      'layout--container--small' => $this->t('Small'),
      'layout--container--large' => $this->t('Large'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function getColorsOptions() {
    return [
      'layout--color--default' => $this->t('Default'),
      'layout--color--black' => $this->t('Black'),
      'layout--color--white' => $this->t('White'),
      'layout--color--grey' => $this->t('Grey'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  protected function enableImageBackground() {
    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  protected function getDefaultBackgroundPosition() {
    return 'layout--background-position--center';
  }

  /**
   * {@inheritdoc}
   */
  protected function getDefaultBackgroundSize() {
    return 'layout--background-size--cover';
  }

  /**
   * {@inheritdoc}
   */
  public function build(array $regions) {
    $build = parent::build($regions);
    $build['#attached']['library'][] = 'layout_builder_base_library/layout-builder-base-library';
    return $build;
  }

}
